@@ -2,7 +2,7 @@ import numpy as np
 
 from ..tools import chi2_approx
 from ._utils import _CheckInputs
-from .base import IndependenceTest
+from .base import IndependenceTest, IndependenceTestOutput
 from .cca import CCA
 from .dcorr import Dcorr
 from .hhg import HHG
@@ -28,13 +28,11 @@ class MaxMargin(IndependenceTest):
 
     This test loops over each of the dimensions of the inputs :math:`x` and :math:`y`
     and computes the desired independence test statistic. Then, the maximial test
-    statistic is chosen `[1]`_.
+    statistic is chosen :footcite:p:`shenHighDimensionalIndependenceTesting2020`.
 
     The p-value returned is calculated using a permutation test using
     :meth:`hyppo.tools.perm_test`.
 
-    .. _[1]: https://arxiv.org/abs/2001.01095
-
     Parameters
     ----------
     indep_test : "CCA", "Dcorr", "HHG", "RV", "Hsic", "MGC", "KMERF"
@@ -73,6 +71,10 @@ class MaxMargin(IndependenceTest):
         ``indep_test="Dcorr"`` and ``indep_test="Hsic"``).
     **kwargs
         Arbitrary keyword arguments for ``compute_distkern``.
+
+    References
+    ----------
+    .. footbibliography::
     """
 
     def __init__(self, indep_test, compute_distkern="euclidean", bias=False, **kwargs):
@@ -92,10 +94,11 @@ class MaxMargin(IndependenceTest):
             "rv": {},
             "cca": {},
         }
-
         self.indep_test = INDEP_NOT_MAXMARGIN[indep_test](
             **indep_kwargs[indep_test], **kwargs
         )
+        self.is_fast = False
+        self.bias = bias
 
         IndependenceTest.__init__(self, compute_distance=compute_distkern, **kwargs)
 
@@ -129,7 +132,7 @@ class MaxMargin(IndependenceTest):
 
         return stat
 
-    def test(self, x, y, reps=1000, workers=1, auto=True):
+    def test(self, x, y, reps=1000, workers=1, auto=True, random_state=None):
         r"""
         Calculates the Maximal Margin test statistic and p-value.
 
@@ -182,6 +185,15 @@ class MaxMargin(IndependenceTest):
         )
         x, y = check_input()
 
+        if (
+            auto
+            and x.shape[1] == 1
+            and y.shape[1] == 1
+            and self.compute_distance == "euclidean"
+            and self.indep_test_name == "dcorr"
+        ):
+            self.is_fast = True
+
         if auto and x.shape[0] > 20 and self.indep_test_name in ["dcorr", "hsic"]:
             stat, pvalue = chi2_approx(self.statistic, x, y)
             self.stat = stat
@@ -189,7 +201,7 @@ class MaxMargin(IndependenceTest):
             self.null_dist = None
         else:
             stat, pvalue = super(MaxMargin, self).test(
-                x, y, reps, workers, is_distsim=False
+                x, y, reps, workers, is_distsim=False, random_state=None
             )
 
-        return stat, pvalue
+        return IndependenceTestOutput(stat, pvalue)
