@@ -1,5 +1,7 @@
 import warnings
+from typing import NamedTuple
 
+import numpy as np
 from scipy.stats import multiscale_graphcorr
 
 from ..tools import compute_dist
@@ -7,13 +9,21 @@ from ._utils import _CheckInputs
 from .base import IndependenceTest
 
 
+class MGCestOutput(NamedTuple):
+    stat: float
+    pvalue: float
+    mgc_dict: dict
+
+
 class MGC(IndependenceTest):
     r"""
     Multiscale Graph Correlation (MGC) test statistic and p-value.
 
     Specifically, for each point, MGC finds the :math:`k`-nearest neighbors for
     one property (e.g. cloud density), and the :math:`l`-nearest neighbors for
-    the other property (e.g. grass wetness) `[1]`_. This pair :math:`(k, l)` is
+    the other property (e.g. grass wetness)
+    :footcite:p:`vogelsteinDiscoveringDecipheringRelationships2019`.
+    This pair :math:`(k, l)` is
     called the "scale". A priori, however, it is not know which scales will be
     most informative. So, MGC computes all distance pairs, and then efficiently
     computes the distance correlations for all scales. The local correlations
@@ -26,53 +36,8 @@ class MGC(IndependenceTest):
     determination was made. This is especially important in high-dimensional
     data, where simple visualizations do not reveal relationships to the
     unaided human eye. Characterizations of this implementation in particular
-    have been derived from and benchmarked within in `[2]`_.
-    A description of the process of MGC and applications on neuroscience data
-    can be found in `[1]`_. It is performed using the following steps:
-
-    Let :math:`x` and :math:`y` be :math:`(n, p)` samples of random variables
-    :math:`X` and :math:`Y`. Let :math:`D^x` be the :math:`n \times n`
-    distance matrix of :math:`x` and :math:`D^y` be the :math:`n \times n` be
-    the distance matrix of :math:`y`. :math:`D^x` and :math:`D^y` are
-    modified to be mean zero columnwise. This results in two
-    :math:`n \times n` distance matrices :math:`A` and :math:`B` (the
-    centering and unbiased modification) `[3]`_.
-
-    + For all values :math:`k` and :math:`l` from :math:`1, ..., n`,
-
-       * The :math:`k`-nearest neighbor and :math:`l`-nearest neighbor graphs
-         are calculated for each property. Here, :math:`G_k (i, j)` indicates
-         the :math:`k`-smallest values of the :math:`i`-th row of :math:`A`
-         and :math:`H_l (i, j)` indicates the :math:`l` smallested values of
-         the :math:`i`-th row of :math:`B`
-
-       * The local
-         correlations are summed and normalized using the following statistic:
-
-         .. math::
-
-            c^{kl} = \frac{\sum_{ij} A G_k B H_l}
-                            {\sqrt{\sum_{ij} A^2 G_k \times \sum_{ij} B^2 H_l}}
-
-    + The MGC test statistic is the smoothed optimal local correlation of
-      :math:`\{ c^{kl} \}`. Denote the smoothing operation as :math:`R(\cdot)`
-      (which essentially set all isolated large correlations) as 0 and
-      connected large correlations the same as before, see `[3]`_.) MGC is,
-
-      .. math::
-
-         \mathrm{MGC}_n (x, y) = \max_{(k, l)} R \left(c^{kl} \left( x_n, y_n \right)
-                                                    \right)
-
-    The test statistic returns a value between :math:`(-1, 1)` since it is
-    normalized.
-
-    The p-value returned is calculated using a permutation test using
-    :meth:`hyppo.tools.perm_test`.
-
-    .. _[1]: https://elifesciences.org/articles/41690
-    .. _[2]: https://arxiv.org/abs/1907.02088
-    .. _[3]: https://www.tandfonline.com/doi/abs/10.1080/01621459.2018.1543125
+    have been derived from and benchmarked within
+    :footcite:t:`pandaHyppoMultivariateHypothesis2021`.
 
     Parameters
     ----------
@@ -102,6 +67,60 @@ class MGC(IndependenceTest):
         function.
     **kwargs
         Arbitrary keyword arguments for ``compute_distance``.
+
+    Notes
+    -----
+    A description of the process of MGC and applications on neuroscience data
+    can be found in
+    :footcite:t:`vogelsteinDiscoveringDecipheringRelationships2019`.
+    It is performed using the following steps:
+
+    Let :math:`x` and :math:`y` be :math:`(n, p)` samples of random variables
+    :math:`X` and :math:`Y`. Let :math:`D^x` be the :math:`n \times n`
+    distance matrix of :math:`x` and :math:`D^y` be the :math:`n \times n` be
+    the distance matrix of :math:`y`. :math:`D^x` and :math:`D^y` are
+    modified to be mean zero columnwise. This results in two
+    :math:`n \times n` distance matrices :math:`A` and :math:`B` (the
+    centering and unbiased modification)
+    :footcite:p:`shenDistanceCorrelationMultiscale2020`.
+
+    + For all values :math:`k` and :math:`l` from :math:`1, ..., n`,
+
+       * The :math:`k`-nearest neighbor and :math:`l`-nearest neighbor graphs
+         are calculated for each property. Here, :math:`G_k (i, j)` indicates
+         the :math:`k`-smallest values of the :math:`i`-th row of :math:`A`
+         and :math:`H_l (i, j)` indicates the :math:`l` smallested values of
+         the :math:`i`-th row of :math:`B`
+
+       * The local
+         correlations are summed and normalized using the following statistic:
+
+         .. math::
+
+            c^{kl} = \frac{\sum_{ij} A G_k B H_l}
+                            {\sqrt{\sum_{ij} A^2 G_k \times \sum_{ij} B^2 H_l}}
+
+    + The MGC test statistic is the smoothed optimal local correlation of
+      :math:`\{ c^{kl} \}`. Denote the smoothing operation as :math:`R(\cdot)`
+      (which essentially set all isolated large correlations) as 0 and
+      connected large correlations the same as before, see
+      :footcite:t:`shenDistanceCorrelationMultiscale2020`.)
+      MGC is,
+
+      .. math::
+
+         \mathrm{MGC}_n (x, y) = \max_{(k, l)} R \left(c^{kl} \left( x_n, y_n \right)
+                                                    \right)
+
+    The test statistic returns a value between :math:`(-1, 1)` since it is
+    normalized.
+
+    The p-value returned is calculated using a permutation test using
+    :meth:`hyppo.tools.perm_test`.
+
+    References
+    ----------
+    .. footbibliography::
     """
 
     def __init__(self, compute_distance="euclidean", **kwargs):
@@ -146,7 +165,7 @@ class MGC(IndependenceTest):
 
         return stat
 
-    def test(self, x, y, reps=1000, workers=1):
+    def test(self, x, y, reps=1000, workers=1, random_state=None):
         r"""
         Calculates the MGC test statistic and p-value.
 
@@ -209,6 +228,22 @@ class MGC(IndependenceTest):
         )
         x, y = check_input()
 
+        # add test for redundant rows
+        if (
+            np.unique(x, axis=0).shape[0] != x.shape[0]
+            or np.unique(y, axis=0).shape[0] != y.shape[0]
+        ):
+            warnings.warn(
+                "Input x has {} redundant rows, and input y has {} redundant "
+                "rows. MGC Map will be of shape ({}, {}).".format(
+                    x.shape[0] - np.unique(x, axis=0).shape[0],
+                    y.shape[0] - np.unique(y, axis=0).shape[0],
+                    np.unique(x, axis=0).shape[0],
+                    np.unique(y, axis=0).shape[0],
+                ),
+                RuntimeWarning,
+            )
+
         x, y = compute_dist(x, y, metric=self.compute_distance, **self.kwargs)
         self.is_distance = True
 
@@ -219,7 +254,9 @@ class MGC(IndependenceTest):
             _, _, mgc_dict = multiscale_graphcorr(x, y, compute_distance=None, reps=0)
         mgc_dict.pop("null_dist")
 
-        stat, pvalue = super(MGC, self).test(x, y, reps, workers)
+        stat, pvalue = super(MGC, self).test(
+            x, y, reps, workers, random_state=random_state
+        )
         self.mgc_dict = mgc_dict
 
-        return stat, pvalue, mgc_dict
+        return MGCestOutput(stat, pvalue, mgc_dict)
