@@ -18,6 +18,15 @@ class TestRVStat:
         assert_almost_equal(stat, obs_stat, decimal=2)
         assert_almost_equal(pvalue, obs_pvalue, decimal=2)
 
+    @pytest.mark.parametrize("n", [100, 1000])
+    def test_rep(self, n):
+        x, y = linear(n, 1)
+        stat1, pvalue1 = RV().test(x, y)
+        stat2, pvalue2 = RV().test(x, y)
+
+        assert stat1 == stat2
+        assert pvalue1 == pvalue2
+
 
 class TestCCATypeIError:
     def test_oned(self):
