@@ -1,8 +1,16 @@
+from typing import NamedTuple
+
 from ..independence import Dcorr
 from ._utils import _CheckInputs, compute_stat
 from .base import TimeSeriesTest
 
 
+class DcorrXTestOutput(NamedTuple):
+    stat: float
+    pvalue: float
+    dcorrx_dict: dict
+
+
 class DcorrX(TimeSeriesTest):
     r"""
     Cross Distance Correlation (DcorrX) test statistic and p-value.
@@ -11,22 +19,6 @@ class DcorrX(TimeSeriesTest):
     not necessarily equal dimensions. The population parameter is 0 if and only if the
     time series are independent. It is based upon energy distance between distributions.
 
-    The statistic can be derived as follows `[1]`_:
-
-    Let :math:`x` and :math:`y` be :math:`(n, p)` and :math:`(n, q)` series
-    respectively, which each contain :math:`y` observations of the series
-    :math:`(X_t)` and :math:`(Y_t)`. Similarly, let :math:`x[j:n]` be the
-    :math:`(n-j, p)` last :math:`n-j` observations of :math:`x`. Let :math:`y[0:(n-j)]`
-    be the :math:`(n-j, p)` first :math:`n-j` observations of :math:`y`. Let :math:`M`
-    be the maximum lag hyperparameter. The cross distance correlation is,
-
-    .. math::
-
-        \mathrm{DcorrX}_n (x, y) =  \sum_{j=0}^M \frac{n-j}{n}
-                                    Dcorr_n (x[j:n], y[0:(n-j)])
-
-    The p-value returned is calculated using a permutation test.
-
     .. _[1]: https://arxiv.org/abs/1908.06486
 
     Parameters
@@ -60,6 +52,29 @@ class DcorrX(TimeSeriesTest):
         shifted ``y``. Also the ``M`` hyperparmeter below.
     **kwargs
         Arbitrary keyword arguments for ``compute_distance``.
+
+    Notes
+    -----
+    The statistic can be derived as follows
+    :footcite:p:`mehtaIndependenceTestingMultivariate2020`:
+
+    Let :math:`x` and :math:`y` be :math:`(n, p)` and :math:`(n, q)` series
+    respectively, which each contain :math:`y` observations of the series
+    :math:`(X_t)` and :math:`(Y_t)`. Similarly, let :math:`x[j:n]` be the
+    :math:`(n-j, p)` last :math:`n-j` observations of :math:`x`. Let :math:`y[0:(n-j)]`
+    be the :math:`(n-j, p)` first :math:`n-j` observations of :math:`y`. Let :math:`M`
+    be the maximum lag hyperparameter. The cross distance correlation is,
+
+    .. math::
+
+        \mathrm{DcorrX}_n (x, y) =  \sum_{j=0}^M \frac{n-j}{n}
+                                    Dcorr_n (x[j:n], y[0:(n-j)])
+
+    The p-value returned is calculated using a permutation test.
+
+    References
+    ----------
+    .. footbibliography::
     """
 
     def __init__(self, compute_distance="euclidean", max_lag=0, **kwargs):
@@ -95,7 +110,7 @@ class DcorrX(TimeSeriesTest):
 
         return stat, opt_lag
 
-    def test(self, x, y, reps=1000, workers=1):
+    def test(self, x, y, reps=1000, workers=1, random_state=None):
         r"""
         Calculates the DcorrX test statistic and p-value.
 
@@ -135,7 +150,7 @@ class DcorrX(TimeSeriesTest):
         >>> y = x
         >>> stat, pvalue, dcorrx_dict = DcorrX().test(x, y, reps = 100)
         >>> '%.1f, %.2f, %d' % (stat, pvalue, dcorrx_dict['opt_lag'])
-        '1.0, 0.01, 0'
+        '1.0, 0.04, 0'
         """
         check_input = _CheckInputs(
             x,
@@ -144,6 +159,8 @@ class DcorrX(TimeSeriesTest):
         )
         x, y = check_input()
 
-        stat, pvalue, stat_list = super(DcorrX, self).test(x, y, reps, workers)
+        stat, pvalue, stat_list = super(DcorrX, self).test(
+            x, y, reps, workers, random_state
+        )
         dcorrx_dict = {"opt_lag": stat_list[1]}
-        return stat, pvalue, dcorrx_dict
+        return DcorrXTestOutput(stat, pvalue, dcorrx_dict)
