@@ -1,8 +1,16 @@
+from typing import NamedTuple
+
 from ..independence import MGC
 from ._utils import _CheckInputs, compute_scale_at_lag, compute_stat
 from .base import TimeSeriesTest
 
 
+class MGCXTestOutput(NamedTuple):
+    stat: float
+    pvalue: float
+    mgcx_dict: dict
+
+
 class MGCX(TimeSeriesTest):
     r"""
     Cross Multiscale Graph Correlation (MGCX) test statistic and p-value.
@@ -11,20 +19,6 @@ class MGCX(TimeSeriesTest):
     not necessarily equal dimensions. The population parameter is 0 if and only if the
     time series are independent. It is based upon energy distance between distributions.
 
-    The statistic can be derived as follows `[1]`_:
-
-    Let :math:`x` and :math:`y` be :math:`(n, p)` and :math:`(n, q)` series
-    respectively, which each contain :math:`y` observations of the series :math:`(X_t)`
-    and :math:`(Y_t)`. Similarly, let :math:`x[j:n]` be the :math:`(n-j, p)` last
-    :math:`n-j` observations of :math:`x`. Let :math:`y[0:(n-j)]` be the
-    :math:`(n-j, p)` first :math:`n-j` observations of :math:`y`. Let :math:`M` be the
-    maximum lag hyperparameter. The cross distance correlation is,
-
-    .. math::
-
-        \mathrm{MGCX}_n (x, y) =  \sum_{j=0}^M \frac{n-j}{n}
-                                  MGC_n (x[j:n], y[0:(n-j)])
-
     .. _[1]: https://arxiv.org/abs/1908.06486
 
     Parameters
@@ -58,6 +52,27 @@ class MGCX(TimeSeriesTest):
         shifted ``y``. Also the ``M`` hyperparmeter below.
     **kwargs
         Arbitrary keyword arguments for ``compute_distance``.
+
+    Notes
+    -----
+    The statistic can be derived as follows
+    :footcite:p:`mehtaIndependenceTestingMultivariate2020`:
+
+    Let :math:`x` and :math:`y` be :math:`(n, p)` and :math:`(n, q)` series
+    respectively, which each contain :math:`y` observations of the series :math:`(X_t)`
+    and :math:`(Y_t)`. Similarly, let :math:`x[j:n]` be the :math:`(n-j, p)` last
+    :math:`n-j` observations of :math:`x`. Let :math:`y[0:(n-j)]` be the
+    :math:`(n-j, p)` first :math:`n-j` observations of :math:`y`. Let :math:`M` be the
+    maximum lag hyperparameter. The cross distance correlation is,
+
+    .. math::
+
+        \mathrm{MGCX}_n (x, y) =  \sum_{j=0}^M \frac{n-j}{n}
+                                  MGC_n (x[j:n], y[0:(n-j)])
+
+    References
+    ----------
+    .. footbibliography::
     """
 
     def __init__(self, compute_distance="euclidean", max_lag=0, **kwargs):
@@ -101,7 +116,7 @@ class MGCX(TimeSeriesTest):
 
         return stat, opt_lag, opt_scale
 
-    def test(self, x, y, reps=1000, workers=1):
+    def test(self, x, y, reps=1000, workers=1, random_state=None):
         r"""
         Calculates the MGCX test statistic and p-value.
 
@@ -155,7 +170,7 @@ class MGCX(TimeSeriesTest):
         >>> stat, pvalue, mgcx_dict = MGCX().test(x, y, reps = 100)
         >>> '%.1f, %.2f, [%d, %d]' % (stat, pvalue, mgcx_dict['opt_scale'][0],
         ... mgcx_dict['opt_scale'][1])
-        '1.0, 0.03, [7, 7]'
+        '1.0, 0.05, [7, 7]'
 
         The increasing the max_lag can increase the ability to identify dependence.
 
@@ -175,7 +190,9 @@ class MGCX(TimeSeriesTest):
         )
         x, y = check_input()
 
-        stat, pvalue, stat_list = super(MGCX, self).test(x, y, reps, workers)
+        stat, pvalue, stat_list = super(MGCX, self).test(
+            x, y, reps, workers, random_state
+        )
         mgcx_dict = {"opt_lag": stat_list[1], "opt_scale": stat_list[2]}
 
-        return stat, pvalue, mgcx_dict
+        return MGCXTestOutput(stat, pvalue, mgcx_dict)
