@@ -6,6 +6,7 @@ from scipy.stats.distributions import chi2
 from scipy.stats.stats import _contains_nan
 from sklearn.metrics import pairwise_distances
 from sklearn.metrics.pairwise import pairwise_kernels
+from sklearn.utils import check_random_state
 
 
 def contains_nan(a):  # from scipy
@@ -113,12 +114,13 @@ def compute_kern(x, y, metric="gaussian", workers=1, **kwargs):
         Valid strings for ``metric`` are, as defined in
         :func:`sklearn.metrics.pairwise.pairwise_kernels`,
 
-            ['additive_chi2', 'chi2', 'linear', 'poly', 'polynomial', 'rbf',
-            'laplacian', 'sigmoid', 'cosine']
+            [``"additive_chi2"``, ``"chi2"``, ``"linear"``, ``"poly"``,
+            ``"polynomial"``, ``"rbf"``,
+            ``"laplacian"``, ``"sigmoid"``, ``"cosine"``]
 
-        Note ``'rbf'`` and ``'gaussian'`` are the same metric.
-        Set to ``None`` or ``'precomputed'`` if ``x`` and ``y`` are already similarity
-        matrices. To call a custom function, either create the distance matrix
+        Note ``"rbf"`` and ``"gaussian"`` are the same metric.
+        Set to ``None`` or ``"precomputed"`` if ``x`` and ``y`` are already similarity
+        matrices. To call a custom function, either create the similarity matrix
         before-hand or create a function of the form :func:`metric(x, **kwargs)`
         where ``x`` is the data matrix for which pairwise kernel similarity matrices are
         calculated and kwargs are extra arguements to send to your custom function.
@@ -137,13 +139,14 @@ def compute_kern(x, y, metric="gaussian", workers=1, **kwargs):
     """
     if not metric:
         metric = "precomputed"
-    if metric == "gaussian":
+    if metric in ["gaussian", "rbf"]:
         if "gamma" not in kwargs:
-            l1 = pairwise_distances(x, metric="l1", n_jobs=workers)
-            n = l1.shape[0]
+            l2 = pairwise_distances(x, metric="l2", n_jobs=workers)
+            n = l2.shape[0]
+            # compute median of off diagonal elements
             med = np.median(
                 np.lib.stride_tricks.as_strided(
-                    l1, (n - 1, n + 1), (l1.itemsize * (n + 1), l1.itemsize)
+                    l2, (n - 1, n + 1), (l2.itemsize * (n + 1), l2.itemsize)
                 )[:, 1:]
             )
             # prevents division by zero when used on label vectors
@@ -180,16 +183,19 @@ def compute_dist(x, y, metric="euclidean", workers=1, **kwargs):
         Valid strings for ``metric`` are, as defined in
         :func:`sklearn.metrics.pairwise_distances`,
 
-            - From scikit-learn: [‘cityblock’, ‘cosine’, ‘euclidean’, ‘l1’, ‘l2’,
-              ‘manhattan’] See the documentation for scipy.spatial.distance for details
+            - From scikit-learn: [``"euclidean"``, ``"cityblock"``, ``"cosine"``,
+              ``"l1"``, ``"l2"``, ``"manhattan"``] See the documentation for
+              :mod:`scipy.spatial.distance` for details
               on these metrics.
-            - From scipy.spatial.distance: [‘braycurtis’, ‘canberra’, ‘chebyshev’,
-              ‘correlation’, ‘dice’, ‘hamming’, ‘jaccard’, ‘kulsinski’, ‘mahalanobis’,
-              ‘minkowski’, ‘rogerstanimoto’, ‘russellrao’, ‘seuclidean’,
-              ‘sokalmichener’, ‘sokalsneath’, ‘sqeuclidean’, ‘yule’] See the
-              documentation for scipy.spatial.distance for details on these metrics.
+            - From scipy.spatial.distance: [``"braycurtis"``, ``"canberra"``,
+              ``"chebyshev"``, ``"correlation"``, ``"dice"``, ``"hamming"``,
+              ``"jaccard"``, ``"kulsinski"``, ``"mahalanobis"``, ``"minkowski"``,
+              ``"rogerstanimoto"``, ``"russellrao"``, ``"seuclidean"``,
+              ``"sokalmichener"``, ``"sokalsneath"``, ``"sqeuclidean"``,
+              ``"yule"``] See the documentation for :mod:`scipy.spatial.distance` for
+              details on these metrics.
 
-        Set to ``None`` or ``'precomputed'`` if ``x`` and ``y`` are already distance
+        Set to ``None`` or ``"precomputed"`` if ``x`` and ``y`` are already distance
         matrices. To call a custom function, either create the distance matrix
         before-hand or create a function of the form ``metric(x, **kwargs)``
         where ``x`` is the data matrix for which pairwise distances are
@@ -311,7 +317,9 @@ class _PermTree(object):
                 root.add_child(child_node)
                 self._add_levels(child_node, perm_blocks[idxs, 1:], indices[idxs])
 
-    def _permute_level(self, node):
+    def _permute_level(self, node, rng=None):
+        if rng is None:
+            rng = np.random
         if len(node.get_children()) == 0:
             return [node.index]
         else:
@@ -324,13 +332,11 @@ class _PermTree(object):
             shuffle_children = [i for i, label in enumerate(labels) if label >= 0]
             indices = np.asarray(indices)
             if len(shuffle_children) > 1:
-                indices[shuffle_children] = indices[
-                    np.random.permutation(shuffle_children)
-                ]
+                indices[shuffle_children] = indices[rng.permutation(shuffle_children)]
             return np.concatenate(indices)
 
-    def permute_indices(self):
-        return self._permute_level(self.root)[self._index_order]
+    def permute_indices(self, rng=None):
+        return self._permute_level(self.root, rng)[self._index_order]
 
     def original_indices(self):
         return np.arange(len(self._index_order))
@@ -347,22 +353,25 @@ class _PermGroups(object):
         else:
             self.perm_tree = _PermTree(perm_blocks)
 
-    def __call__(self):
+    def __call__(self, rng=None):
+        if rng is None:
+            rng = np.random
         if self.perm_tree is None:
-            order = np.random.permutation(self.n)
+            order = rng.permutation(self.n)
         else:
-            order = self.perm_tree.permute_indices()
+            order = self.perm_tree.permute_indices(rng)
 
         return order
 
 
 # p-value computation
-def _perm_stat(calc_stat, x, y, is_distsim=True, permuter=None):
+def _perm_stat(calc_stat, x, y, is_distsim=True, permuter=None, random_state=None):
     """Permute the test statistic"""
-    if not permuter:
-        order = np.random.permutation(y.shape[0])
+    rng = check_random_state(random_state)
+    if permuter is None:
+        order = rng.permutation(y.shape[0])
     else:
-        order = permuter()
+        order = permuter(rng)
 
     if is_distsim:
         permy = y[order][:, order]
@@ -374,7 +383,16 @@ def _perm_stat(calc_stat, x, y, is_distsim=True, permuter=None):
     return perm_stat
 
 
-def perm_test(calc_stat, x, y, reps=1000, workers=1, is_distsim=True, perm_blocks=None):
+def perm_test(
+    calc_stat,
+    x,
+    y,
+    reps=1000,
+    workers=1,
+    is_distsim=True,
+    perm_blocks=None,
+    random_state=None,
+):
     """
     Permutation test for the p-value of a nonparametric test.
 
@@ -404,14 +422,13 @@ def perm_test(calc_stat, x, y, reps=1000, workers=1, is_distsim=True, perm_block
         Whether or not ``x`` and ``y`` are distance or similarity matrices.
     perm_blocks : ndarray, default: None
         Defines blocks of exchangeable samples during the permutation test.
-        If None, all samples can be permuted with one another. Requires `n`
+        If ``None``, all samples can be permuted with one another. Requires `n`
         rows. Constructs a tree graph with all samples initially at
         the root node. Each column partitions samples from the same leaf with
         shared column label into a child of that leaf. During the permutation
         test, samples within the same final leaf node are exchangeable
         and blocks of samples with a common parent node are exchangeable. If a
         column value is negative, the resulting block is unexchangeable.
-
     Returns
     -------
     stat : float
@@ -424,13 +441,23 @@ def perm_test(calc_stat, x, y, reps=1000, workers=1, is_distsim=True, perm_block
     # calculate observed test statistic
     stat = calc_stat(x, y)
 
+    # make RandomState seeded array
+    if random_state is not None:
+        rng = check_random_state(random_state)
+        random_state = rng.randint(np.iinfo(np.int32).max, size=reps)
+
+    # make random array
+    else:
+        random_state = np.random.randint(np.iinfo(np.int32).max, size=reps)
+
     # calculate null distribution
     permuter = _PermGroups(y, perm_blocks)
+
     null_dist = np.array(
         Parallel(n_jobs=workers)(
             [
-                delayed(_perm_stat)(calc_stat, x, y, is_distsim, permuter)
-                for _ in range(reps)
+                delayed(_perm_stat)(calc_stat, x, y, is_distsim, permuter, rng)
+                for rng in random_state
             ]
         )
     )
@@ -444,13 +471,12 @@ def chi2_approx(calc_stat, x, y):
     Fast chi-squared approximation for the p-value.
 
     In the case of distance and kernel methods, Dcorr (and by extension Hsic
-    `[2]`_) can be approximated via a chi-squared distribution `[1]`_.
+    :footcite:p:`shenExactEquivalenceDistance2020`)
+    can be approximated via a chi-squared distribution
+    :footcite:p:`shenChiSquareTestDistance2021`.
     This approximation is also applicable for the nonparametric MANOVA via
-    independence testing method in our package `[3]`_.
-
-    .. _[1]: https://arxiv.org/abs/1912.12150
-    .. _[2]: https://arxiv.org/abs/1806.05514
-    .. _[3]: https://arxiv.org/abs/1910.08883
+    independence testing method in our package
+    :footcite:p:`pandaNonparMANOVAIndependence2021`.
 
     Parameters
     ----------
@@ -470,6 +496,10 @@ def chi2_approx(calc_stat, x, y):
         The computed test statistic.
     pvalue : float
         The computed p-value.
+
+    References
+    ----------
+    .. footbibliography::
     """
     n = x.shape[0]
     stat = calc_stat(x, y)
