@@ -1099,7 +1099,7 @@ def indep_sim(sim, n, p, **kwargs):
     Parameters
     ----------
     sim : str
-        The name of the simulation (from the :mod:`hyppo.tools module) that is to be
+        The name of the simulation (from the :mod:`hyppo.tools` module) that is to be
         rotated.
     n : int
         The number of samples desired by the simulation (>= 5).
